@@ -1,5 +1,7 @@
 package org.ovirt.engine.core.dao;
 
+import java.util.List;
+
 import org.ovirt.engine.core.common.businessentities.storage.ImageTransfer;
 import org.ovirt.engine.core.compat.Guid;
 
@@ -11,6 +13,13 @@ public interface ImageTransferDao extends GenericDao<ImageTransfer, Guid>, Searc
      */
     ImageTransfer getByDiskId(Guid diskId);
 
+    /**
+     * Retrieves an ImageTransfer entities based on vds id
+     *
+     * @return ImageTransfer entity
+     */
+    List<ImageTransfer> getByVdsId(Guid vdsId);
+
     /**
      *
      * @return ImageTransfer entity
