@@ -106,7 +106,7 @@ public class V3TemplateServer extends V3Server<TemplateResource> {
         return new V3TemplateWatchdogsServer(getDelegate().getWatchdogsResource());
     }
 
-    @Path("{action: (export)}/{oid}")
+    @Path("{action: (?:export)}/{oid}")
     public V3ActionServer getActionResource(@PathParam("action") String action, @PathParam("oid") String oid) {
         return new V3ActionServer(getDelegate().getActionResource(action, oid));
     }
