@@ -18,6 +18,7 @@ import java.util.Objects;
 import java.util.Optional;
 import java.util.Set;
 import java.util.TimeZone;
+import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
@@ -72,6 +73,7 @@ import org.ovirt.engine.core.common.businessentities.storage.VolumeFormat;
 import org.ovirt.engine.core.common.config.Config;
 import org.ovirt.engine.core.common.config.ConfigValues;
 import org.ovirt.engine.core.common.osinfo.OsRepository;
+import org.ovirt.engine.core.common.utils.PDIVMapBuilder;
 import org.ovirt.engine.core.common.utils.ValidationUtils;
 import org.ovirt.engine.core.common.utils.VmDeviceCommonUtils;
 import org.ovirt.engine.core.common.utils.VmDeviceType;
@@ -539,6 +541,8 @@ public class VmInfoBuildUtils {
         // Find available unit (disk's index in VirtIO-SCSI controller) for disks with empty address\
         IntStream.range(0, vmDeviceList.size()).forEach(index -> {
             VmDevice vmDevice = vmDeviceList.get(index);
+            // TODO: consider changing this so that it will search for the next available and
+            // less used controller instead of always starting from index.
             int controller = getControllerForScsiDisk(vmDevice, vm, index);
 
             if (!vmDeviceUnitMap.containsKey(controller)) {
@@ -606,18 +610,19 @@ public class VmInfoBuildUtils {
         return defaultIndex;
     }
 
-    public List<Disk> getSortedDisks(Map<Disk, VmDevice> disksToDevices, Guid vmId) {
+    public List<Entry<Disk, VmDevice>> getSortedDisks(Map<Disk, VmDevice> disksToDevices, Guid vmId) {
         // Order the drives as following:
         // - Boot devices of non-snapshot disks
         // - Device address of the disk
         // - Boot devices of snapshot disks (i.e., boot disks of other VMs plugged to this one
         // - Then by the disk alias
-        List<Disk> disks = new ArrayList<>(disksToDevices.keySet());
-        disks.sort(Comparator.comparing((Disk d) -> !d.getDiskVmElementForVm(vmId).isBoot())
-                .thenComparing(d -> StringUtils.isEmpty(disksToDevices.get(d).getAddress()))
-                .thenComparing(d -> d.getDiskVmElementForVm(vmId).isBoot() && d.isDiskSnapshot())
-                .thenComparing(new LexoNumericNameableComparator<>()));
-        return disks;
+        List<Entry<Disk, VmDevice>> diskAndDevicePairs = new ArrayList<>(disksToDevices.entrySet());
+        diskAndDevicePairs.sort(
+                Comparator.comparing((Entry<Disk, VmDevice> e) -> !e.getKey().getDiskVmElementForVm(vmId).isBoot())
+                .thenComparing(e -> StringUtils.isEmpty(e.getValue().getAddress()))
+                .thenComparing(e -> e.getKey().getDiskVmElementForVm(vmId).isBoot() && e.getKey().isDiskSnapshot())
+                .thenComparing(e -> e.getKey(), new LexoNumericNameableComparator<>()));
+        return diskAndDevicePairs;
     }
 
     public List<Disk> getSortedDisks(VM vm) {
@@ -1117,7 +1122,7 @@ public class VmInfoBuildUtils {
     }
 
     public boolean isBlockDomainPath(String path) {
-        return BLOCK_DOMAIN_MATCHER.matcher(path).matches();
+        return path != null && BLOCK_DOMAIN_MATCHER.matcher(path).matches();
     }
 
     public List<VdsNumaNode> getVdsNumaNodes(Guid vdsId) {
@@ -1209,7 +1214,7 @@ public class VmInfoBuildUtils {
         vmDevicesMonitoring.refreshVmDevices(vmId);
     }
 
-    public int pinToIoThreads(VM vm, VmDevice vmDevice, int pinnedDriveIndex) {
+    public int pinToIoThreads(VM vm, int pinnedDriveIndex) {
         // simple round robin e.g. for 2 threads and 4 disks it will be pinned like this:
         // disk 0 -> iothread 1
         // disk 1 -> iothread 2
@@ -1217,4 +1222,77 @@ public class VmInfoBuildUtils {
         // disk 3 -> iothread 2
         return vm.getNumOfIoThreads() != 0 ? pinnedDriveIndex % vm.getNumOfIoThreads() + 1 : 0;
     }
+
+    public void calculateAddressForScsiDisk(VM vm,
+            Disk disk,
+            VmDevice device,
+            Map<Integer, Map<VmDevice, Integer>> vmDeviceSpaprVscsiUnitMap,
+            Map<Integer, Map<VmDevice, Integer>> vmDeviceVirtioScsiUnitMap) {
+
+        Map<DiskInterface, Integer> controllerIndexMap =
+                ArchStrategyFactory.getStrategy(vm.getClusterArch()).run(new GetControllerIndices()).returnValue();
+        int defaultSpaprVscsiControllerIndex = controllerIndexMap.get(DiskInterface.SPAPR_VSCSI);
+        int defaultVirtioScsiControllerIndex = controllerIndexMap.get(DiskInterface.VirtIO_SCSI);
+        Integer unitIndex = null;
+
+        switch (disk.getDiskVmElementForVm(vm.getId()).getDiskInterface()) {
+        case SPAPR_VSCSI:
+            if (StringUtils.isEmpty(device.getAddress())) {
+                unitIndex = vmDeviceSpaprVscsiUnitMap.get(defaultSpaprVscsiControllerIndex).get(device);
+                device.setAddress(createAddressForScsiDisk(defaultSpaprVscsiControllerIndex, unitIndex).toString());
+            }
+            break;
+        case VirtIO_SCSI:
+            int controllerIndex = defaultVirtioScsiControllerIndex;
+            VmDevice deviceFromMap = device;
+            for (Map.Entry<Integer, Map<VmDevice, Integer>> controllerToDevices : vmDeviceVirtioScsiUnitMap.entrySet()) {
+                Optional<VmDevice> maybeDeviceFromMap = controllerToDevices.getValue().keySet().stream()
+                        .filter(d -> d.getId().equals(device.getId()))
+                        .findFirst();
+                if (maybeDeviceFromMap.isPresent()) {
+                    deviceFromMap = maybeDeviceFromMap.get();
+                    controllerIndex = controllerToDevices.getKey();
+                    unitIndex = controllerToDevices.getValue().get(deviceFromMap);
+                    break;
+                }
+            }
+
+            if (StringUtils.isEmpty(deviceFromMap.getAddress())) {
+                if (unitIndex == null) {
+                    // should never get here, but for safety having this fallback and generating a new unit id
+                    unitIndex = getAvailableUnitForScsiDisk(vmDeviceVirtioScsiUnitMap.get(controllerIndex), false);
+                    log.debug("The unit was null for disk '{}' on controller '{}', generating a new one '{}'", disk.getId(), controllerIndex, unitIndex);
+                }
+                device.setAddress(createAddressForScsiDisk(controllerIndex, unitIndex).toString());
+            }
+            break;
+        }
+    }
+
+    public Map<String, String> createDiskUuidsMap(VM vm, String cdPath) {
+        Matcher m = Pattern.compile(ValidationUtils.GUID).matcher(cdPath);
+        m.find();
+        Guid domainId = Guid.createGuidFromString(m.group());
+        m.find();
+        Guid imageId = Guid.createGuidFromString(m.group());
+        m.find();
+        Guid volumeId = Guid.createGuidFromString(m.group());
+        return createDiskUuidsMap(vm.getStoragePoolId(), domainId, imageId, volumeId);
+    }
+
+    public Map<String, String> createDiskUuidsMap(DiskImage diskImage) {
+        return createDiskUuidsMap(
+                diskImage.getStoragePoolId(),
+                diskImage.getStorageIds().get(0),
+                diskImage.getId(),
+                diskImage.getImageId());
+    }
+
+    private Map<String, String> createDiskUuidsMap(Guid poolId, Guid domainId, Guid imageId, Guid volumeId) {
+        return PDIVMapBuilder.create()
+                .setPoolId(poolId)
+                .setDomainId(domainId)
+                .setImageGroupId(imageId)
+                .setVolumeId(volumeId).build();
+    }
 }
