@@ -1,6 +1,7 @@
 package org.ovirt.engine.ui.common.widget.uicommon.disks;
 
 import java.util.ArrayList;
+import java.util.Comparator;
 import java.util.Date;
 import java.util.List;
 
@@ -15,7 +16,6 @@ import org.ovirt.engine.core.common.businessentities.storage.VolumeType;
 import org.ovirt.engine.core.common.utils.SizeConverter;
 import org.ovirt.engine.core.compat.Guid;
 import org.ovirt.engine.core.compat.StringFormat;
-import org.ovirt.engine.core.compat.StringHelper;
 import org.ovirt.engine.ui.common.CommonApplicationConstants;
 import org.ovirt.engine.ui.common.CommonApplicationMessages;
 import org.ovirt.engine.ui.common.CommonApplicationResources;
@@ -27,14 +27,16 @@ import org.ovirt.engine.ui.common.widget.table.column.AbstractDiskSizeColumn;
 import org.ovirt.engine.ui.common.widget.table.column.AbstractEnumColumn;
 import org.ovirt.engine.ui.common.widget.table.column.AbstractFullDateTimeColumn;
 import org.ovirt.engine.ui.common.widget.table.column.AbstractImageResourceColumn;
+import org.ovirt.engine.ui.common.widget.table.column.AbstractLinkColumn;
 import org.ovirt.engine.ui.common.widget.table.column.AbstractTextColumn;
 import org.ovirt.engine.ui.common.widget.table.column.DiskContainersColumn;
 import org.ovirt.engine.ui.common.widget.table.column.DiskProgressColumn;
 import org.ovirt.engine.ui.common.widget.table.column.DiskStatusColumn;
-import org.ovirt.engine.ui.common.widget.table.column.DiskUploadImageProgressColumn;
+import org.ovirt.engine.ui.common.widget.table.column.DiskTransferProgressColumn;
 import org.ovirt.engine.ui.common.widget.table.column.StorageDomainsColumn;
 import org.ovirt.engine.ui.uicompat.EnumTranslator;
 
+import com.google.gwt.cell.client.FieldUpdater;
 import com.google.gwt.cell.client.HasCell;
 import com.google.gwt.i18n.client.DateTimeFormat;
 import com.google.gwt.resources.client.ImageResource;
@@ -48,12 +50,27 @@ public class DisksViewColumns {
     private static final CommonApplicationMessages messages = AssetProvider.getMessages();
 
     public static AbstractTextColumn<Disk> getAliasColumn(String sortBy) {
-        AbstractTextColumn<Disk> column = new AbstractTextColumn<Disk>() {
-            @Override
-            public String getValue(Disk object) {
-                return object.getDiskAlias();
-            }
-        };
+        return getAliasColumn(null, sortBy);
+    }
+
+    public static AbstractTextColumn<Disk> getAliasColumn(FieldUpdater<Disk, String> updater, String sortBy) {
+        AbstractTextColumn<Disk> column;
+
+        if (updater != null) {
+            column = new AbstractLinkColumn<Disk>(updater) {
+                @Override
+                public String getValue(Disk object) {
+                    return object.getName();
+                }
+            };
+        } else {
+            column = new AbstractTextColumn<Disk>() {
+                @Override
+                public String getValue(Disk object) {
+                    return object.getName();
+                }
+            };
+        }
 
         return makeSortable(column, sortBy);
     }
@@ -76,9 +93,9 @@ public class DisksViewColumns {
                 String value = "";
                 if (object.getDiskStorageType() == DiskStorageType.IMAGE) {
                     DiskImage diskImage = (DiskImage) object;
-                    ArrayList<String> quotaNamesArr = diskImage.getQuotaNames();
+                    List<String> quotaNamesArr = diskImage.getQuotaNames();
                     if (quotaNamesArr != null) {
-                        value = StringHelper.join(", ", quotaNamesArr.toArray());//$NON-NLS-1$
+                        value = String.join(", ", quotaNamesArr);//$NON-NLS-1$
                     }
                 }
                 return value;
@@ -119,29 +136,33 @@ public class DisksViewColumns {
         }
     };
 
-    public static final AbstractImageResourceColumn<Disk> shareableDiskColumn = new AbstractImageResourceColumn<Disk>() {
-        {
-            setContextMenuTitle(constants.shareable());
-        }
-
-        @Override
-        public ImageResource getValue(Disk object) {
-            return object.isShareable() ? getDefaultImage() : null;
-        }
-
-        @Override
-        public ImageResource getDefaultImage() {
-            return resources.shareableDiskIcon();
-        }
-
-        @Override
-        public SafeHtml getTooltip(Disk object) {
-            if (object.isShareable()) {
-                return SafeHtmlUtils.fromSafeConstant(constants.shareable());
+    public static AbstractImageResourceColumn<Disk> getShareableDiskColumn() {
+        AbstractImageResourceColumn<Disk> shareableDiskColumn = new AbstractImageResourceColumn<Disk>() {
+            {
+                setContextMenuTitle(constants.shareable());
             }
-            return null;
-        }
-    };
+
+            @Override
+            public ImageResource getValue(Disk object) {
+                return object.isShareable() ? getDefaultImage() : null;
+            }
+
+            @Override
+            public ImageResource getDefaultImage() {
+                return resources.shareableDiskIcon();
+            }
+
+            @Override
+            public SafeHtml getTooltip(Disk object) {
+                if (object.isShareable()) {
+                    return SafeHtmlUtils.fromSafeConstant(constants.shareable());
+                }
+                return null;
+            }
+        };
+        shareableDiskColumn.makeSortable(Comparator.comparing(Disk::isShareable));
+        return shareableDiskColumn;
+    }
 
     public static final AbstractImageResourceColumn<Disk> readOnlyDiskColumn = new AbstractImageResourceColumn<Disk>() {
         {
@@ -150,7 +171,10 @@ public class DisksViewColumns {
 
         @Override
         public ImageResource getValue(Disk object) {
-            return object.getReadOnly() ? getDefaultImage() : null;
+            if (object.getDiskVmElements().size() == 1) {
+                return object.getDiskVmElements().iterator().next().isReadOnly() ? getDefaultImage() : null;
+            }
+            return null;
         }
 
         @Override
@@ -160,8 +184,9 @@ public class DisksViewColumns {
 
         @Override
         public SafeHtml getTooltip(Disk object) {
-            if (object.getReadOnly()) {
-                return SafeHtmlUtils.fromSafeConstant(constants.readOnly());
+            if (object.getDiskVmElements().size() == 1) {
+                return object.getDiskVmElements().iterator().next().isReadOnly() ?
+                        SafeHtmlUtils.fromSafeConstant(constants.readOnly()) : null;
             }
             return null;
         }
@@ -199,7 +224,11 @@ public class DisksViewColumns {
         }
     };
 
-    public static final DiskContainersColumn diskContainersColumn = new DiskContainersColumn();
+    public static final DiskContainersColumn getdiskContainersColumn(String sortBy){
+        DiskContainersColumn diskContainersColumn = new DiskContainersColumn();
+        makeSortable(diskContainersColumn, sortBy);
+        return diskContainersColumn;
+    }
 
     public static final AbstractTextColumn<Disk> diskAlignmentColumn = new AbstractTextColumn<Disk>() {
         @Override
@@ -218,7 +247,11 @@ public class DisksViewColumns {
         }
     };
 
-    public static final StorageDomainsColumn storageDomainsColumn = new StorageDomainsColumn();
+    public static final StorageDomainsColumn getStorageDomainsColumn(String sortBy) {
+        StorageDomainsColumn storageDomainsColumn = new StorageDomainsColumn();
+        makeSortable(storageDomainsColumn, sortBy);
+        return storageDomainsColumn;
+    }
 
     public static final AbstractTextColumn<Disk> storageTypeColumn = new AbstractEnumColumn<Disk, StorageType>() {
         @Override
@@ -329,7 +362,7 @@ public class DisksViewColumns {
     }
 
     public static final AbstractColumn<Disk, Disk> getStatusColumn(String sortBy) {
-        DiskUploadImageProgressColumn uploadImageProgressColumn = new DiskUploadImageProgressColumn();
+        DiskTransferProgressColumn uploadImageProgressColumn = new DiskTransferProgressColumn();
         DiskProgressColumn diskProgressColumn = new DiskProgressColumn();
 
         List<HasCell<Disk, ?>> list = new ArrayList<>();
